==> DifferentialRegulation_1.0.0.tar.gz: DifferentialRegulation/inst/doc/DifferentialRegulation.R <==
## ----setup, echo=FALSE, results="hide"----------------------------------------
knitr::opts_chunk$set(tidy=FALSE, cache=TRUE,
                      dev="png",
                      message=TRUE, error=FALSE, warning=TRUE)

## ----vignettes, eval=FALSE----------------------------------------------------
#  browseVignettes("DifferentialRegulation")

## ----citation-----------------------------------------------------------------
citation("DifferentialRegulation")

## ----Bioconductor_installation, eval=FALSE------------------------------------
#  if (!requireNamespace("BiocManager", quietly=TRUE))
#    install.packages("BiocManager")
#  BiocManager::install("DifferentialRegulation")

## ----load, message=FALSE------------------------------------------------------
library(DifferentialRegulation)

## ----specify_data-dir---------------------------------------------------------
data_dir = system.file("extdata", package = "DifferentialRegulation")

## ----specify_directories------------------------------------------------------
# specify samples ids:
sample_ids = paste0("organoid", c(1:3, 16:18))
# set directories of each sample input data (obtained via alevin-fry):
base_dir = file.path(data_dir, "alevin-fry", sample_ids)

# Note that alevin-fry needs to be run with `--use-mtx` option to store counts in a `quants_mat.mtx` file.
path_to_counts = file.path(base_dir,"/alevin/quants_mat.mtx")
path_to_cell_id = file.path(base_dir,"/alevin/quants_mat_rows.txt")
path_to_gene_id = file.path(base_dir,"/alevin/quants_mat_cols.txt")

## ----specify_directories_EC---------------------------------------------------
path_to_EC_counts = file.path(base_dir,"/alevin/geqc_counts.mtx")
path_to_EC = file.path(base_dir,"/alevin/gene_eqclass.txt.gz")

## ----load_USA_counts----------------------------------------------------------
sce = load_USA(path_to_counts,
               path_to_cell_id,
               path_to_gene_id,
               sample_ids)

## ----cell-type----------------------------------------------------------------
path_to_DF = file.path(data_dir,"DF_cell_types.txt")
DF_cell_types = read.csv(path_to_DF, sep = "\t", header = TRUE)
matches = match(colnames(sce), DF_cell_types$cell_id)
sce$cell_type = DF_cell_types$cell_type[matches]
table(sce$cell_type)

## ----load_EC_counts-----------------------------------------------------------
EC_list = load_EC(path_to_EC_counts,
                  path_to_EC,
                  path_to_cell_id,
                  path_to_gene_id,
                  sample_ids)

## ----samples_design-----------------------------------------------------------
design = data.frame(sample = sample_ids,
                    group = c( rep("3 mon", 3), rep("6 mon", 3) ))
design

## ----sce-test-----------------------------------------------------------------
# sce-based test:
set.seed(169612)
results_USA = DifferentialRegulation(sce = sce,
                                     EC_list = NULL,
                                     design =  design,
                                     sample_col_name = "sample",
                                     group_col_name = "group",
                                     sce_cluster_name = "cell_type")

## ----visualize_results_USA----------------------------------------------------
# sort results by significance:
results_USA = results_USA[ order(results_USA$p_val), ]
# visualize head of results:
head(results_USA)

## ----EC-test------------------------------------------------------------------
# EC-based test:
set.seed(169612)
results_EC = DifferentialRegulation(sce = sce,
                                    EC_list = EC_list,
                                    design =  design,
                                    sample_col_name = "sample",
                                    group_col_name = "group",
                                    sce_cluster_name = "cell_type")

## ----visualize_results_EC-----------------------------------------------------
# sort results by significance:
results_EC = results_EC[ order(results_EC$p_val), ]
# visualize head of results:
head(results_EC)

## ----sessionInfo--------------------------------------------------------------
sessionInfo()

==> DifferentialRegulation_1.0.2.tar.gz: DifferentialRegulation/inst/doc/DifferentialRegulation.R <==
## ----setup, echo=FALSE, results="hide"----------------------------------------
knitr::opts_chunk$set(tidy=FALSE, cache=TRUE,
                      dev="png",
                      message=TRUE, error=FALSE, warning=TRUE)

## ----vignettes, eval=FALSE----------------------------------------------------
#  browseVignettes("DifferentialRegulation")

## ----citation-----------------------------------------------------------------
citation("DifferentialRegulation")

## ----Bioconductor_installation, eval=FALSE------------------------------------
#  if (!requireNamespace("BiocManager", quietly=TRUE))
#    install.packages("BiocManager")
#  BiocManager::install("DifferentialRegulation")

## ----load, message=FALSE------------------------------------------------------
library(DifferentialRegulation)

## ----specify_data-dir---------------------------------------------------------
data_dir = system.file("extdata", package = "DifferentialRegulation")

## ----specify_directories------------------------------------------------------
# specify samples ids:
sample_ids = paste0("organoid", c(1:3, 16:18))
# set directories of each sample input data (obtained via alevin-fry):
base_dir = file.path(data_dir, "alevin-fry", sample_ids)

# Note that alevin-fry needs to be run with `--use-mtx` option to store counts in a `quants_mat.mtx` file.
path_to_counts = file.path(base_dir,"/alevin/quants_mat.mtx")
path_to_cell_id = file.path(base_dir,"/alevin/quants_mat_rows.txt")
path_to_gene_id = file.path(base_dir,"/alevin/quants_mat_cols.txt")

## ----specify_directories_EC---------------------------------------------------
path_to_EC_counts = file.path(base_dir,"/alevin/geqc_counts.mtx")
path_to_EC = file.path(base_dir,"/alevin/gene_eqclass.txt.gz")

## ----load_USA_counts----------------------------------------------------------
sce = load_USA(path_to_counts,
               path_to_cell_id,
               path_to_gene_id,
               sample_ids)

## ----cell-type----------------------------------------------------------------
path_to_DF = file.path(data_dir,"DF_cell_types.txt")
DF_cell_types = read.csv(path_to_DF, sep = "\t", header = TRUE)
matches = match(colnames(sce), DF_cell_types$cell_id)
sce$cell_type = DF_cell_types$cell_type[matches]
table(sce$cell_type)

## ----load_EC_counts-----------------------------------------------------------
EC_list = load_EC(path_to_EC_counts,
                  path_to_EC,
                  path_to_cell_id,
                  path_to_gene_id,
                  sample_ids)

## ----samples_design-----------------------------------------------------------
design = data.frame(sample = sample_ids,
                    group = c( rep("3 mon", 3), rep("6 mon", 3) ))
design

## ----sce-test-----------------------------------------------------------------
# sce-based test:
set.seed(169612)
results_USA = DifferentialRegulation(sce = sce,
                                     EC_list = NULL,
                                     design =  design,
                                     sample_col_name = "sample",
                                     group_col_name = "group",
                                     sce_cluster_name = "cell_type")

## ----EC-test------------------------------------------------------------------
# EC-based test:
set.seed(169612)
results_EC = DifferentialRegulation(sce = sce,
                                    EC_list = EC_list,
                                    design =  design,
                                    sample_col_name = "sample",
                                    group_col_name = "group",
                                    sce_cluster_name = "cell_type")

## ----names-results------------------------------------------------------------
names(results_EC)

## ----visualize_gene_results---------------------------------------------------
DR = results_EC$Differential_results
# We can also sort results by significance, if we want, before visualizing them.
DR = DR[ order(DR$p_val), ]
head(DR)

## ----visualize_US_results-----------------------------------------------------
US = results_EC$US_results
# We can also sort results by significance, if we want, before visualizing them.
US = US[ order(US$p_val), ]
head(US)

## ----visualize_USA_results----------------------------------------------------
USA = results_EC$USA_results
# We can also sort results by significance, if we want, before visualizing them.
USA = USA[ order(USA$p_val), ]
head(USA)

## ----plot_pi------------------------------------------------------------------
plot_pi(results_EC,
        type = "US",
        gene_id = DR$Gene_id[1],
        cluster_id = DR$Cluster_id[1])

## ----plot_pi_USA--------------------------------------------------------------
plot_pi(results_EC,
        type = "USA",
        gene_id = DR$Gene_id[1],
        cluster_id = DR$Cluster_id[1])

## ----sessionInfo--------------------------------------------------------------
sessionInfo()
